@@ -48,7 +48,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         except BaseException as e:
 
 
-            print(f'{Fore.YELLOW}[{time.ctime()}][main/Error] error in initlazing:{e}')
+            print(f'{Fore.RED}[{time.ctime()}][main/Error] error in initlazing:{e}')
 
             print(Fore.RED+r'*\**:( Downloader Crashed! ):**/*')
             sys.exit(self.show())
@@ -62,7 +62,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
     def opencmd(self):
         os.system('cmd')
     def fwa(self):
-        self.print()
+
         self.close()
     def print(self):
         print(f'[{time.ctime()}][main/Info] stopping!')
@@ -80,6 +80,14 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
             self.checkBox_3.toggle()
         self.lineEdit.setText(dic[3])
         self.lineEdit_2.setText(dic[4])
+    def closeEvent(self,event):
+        result = QtWidgets.QMessageBox.question(self,'close','Close?',QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
+        if result == QtWidgets.QMessageBox.Yes:
+            self.print()
+            event.accept()
+
+        else:
+            event.ignore()
     def write(self):
 
         a = open('properties/settings.properties','w')
@@ -182,7 +190,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
                 self.update(f'failed')
 
 
-            print(f'{Fore.YELLOW}[{time.ctime()}][main/Error] error in download:{e},ignored')
+            print(f'{Fore.YELLOW}[{time.ctime()}][main/Warn] error in download:{e},ignored')
 
 
 
